django-fluent-utils
===================

Utility functions for code sharing between *django-fluent-..* modules.

This includes:

* Making integration with modules optional (e.g. django-fluent-pages_, django-taggit_).
* Django compatibility code

This module is mainly used internally between other django-fluent apps.
For the whole list of apps, see http://django-fluent.org/

.. _django-fluent-pages: https://github.com/edoburu/django-fluent-pages
